#[repr(transparent)]pub struct SymbolicSparseRowMat<Inner>(pub Inner);Expand description
generic SymbolicSparseRowMat wrapper
Tuple Fields
0: InnerImplementations
Sourceimpl<Inner> SymbolicSparseRowMat<Inner>
impl<Inner> SymbolicSparseRowMat<Inner>
Sourcepub fn from_inner_ref(inner: &Inner) -> &Self
pub fn from_inner_ref(inner: &Inner) -> &Self
wrap by reference
Sourcepub fn from_inner_mut(inner: &mut Inner) -> &mut Self
pub fn from_inner_mut(inner: &mut Inner) -> &mut Self
wrap by mutable reference
Sourceimpl<'a, Rows: Shape, Cols: Shape, I: Index> SymbolicSparseRowMat<Ref<'a, I, Rows, Cols>>
impl<'a, Rows: Shape, Cols: Shape, I: Index> SymbolicSparseRowMat<Ref<'a, I, Rows, Cols>>
Sourcepub unsafe fn new_unchecked(
nrows: Rows,
ncols: Cols,
row_ptr: &'a [I],
row_nnz: Option<&'a [I]>,
col_idx: &'a [I],
) -> Self
pub unsafe fn new_unchecked( nrows: Rows, ncols: Cols, row_ptr: &'a [I], row_nnz: Option<&'a [I]>, col_idx: &'a [I], ) -> Self
creates a new symbolic matrix view without checking its invariants
safety
see type level documentation.
Sourcepub fn new_checked(
nrows: Rows,
ncols: Cols,
row_ptr: &'a [I],
row_nnz: Option<&'a [I]>,
col_idx: &'a [I],
) -> Self
pub fn new_checked( nrows: Rows, ncols: Cols, row_ptr: &'a [I], row_nnz: Option<&'a [I]>, col_idx: &'a [I], ) -> Self
creates a new symbolic matrix view after checking its invariants
safety
see type level documentation.
Sourcepub fn new_unsorted_checked(
nrows: Rows,
ncols: Cols,
row_ptr: &'a [I],
row_nnz: Option<&'a [I]>,
col_idx: &'a [I],
) -> Self
pub fn new_unsorted_checked( nrows: Rows, ncols: Cols, row_ptr: &'a [I], row_nnz: Option<&'a [I]>, col_idx: &'a [I], ) -> Self
creates a new symbolic matrix view after checking its invariants (excluding soft invariants)
safety
see type level documentation.
Sourcepub fn parts(self) -> (Rows, Cols, &'a [I], Option<&'a [I]>, &'a [I])
pub fn parts(self) -> (Rows, Cols, &'a [I], Option<&'a [I]>, &'a [I])
returns the components of the sparse matrix
- number of rows
- number of columns
- row pointers
- row non-zero counts
- column indices
Sourcepub fn shape(&self) -> (Rows, Cols)
pub fn shape(&self) -> (Rows, Cols)
returns the number of rows and columns of the matrix
Sourcepub fn transpose(self) -> SymbolicSparseColMatRef<'a, I, Cols, Rows>
pub fn transpose(self) -> SymbolicSparseColMatRef<'a, I, Cols, Rows>
returns a view over the transpose of self
Sourcepub fn to_owned(&self) -> Result<SymbolicSparseRowMat<I, Rows, Cols>, FaerError>
pub fn to_owned(&self) -> Result<SymbolicSparseRowMat<I, Rows, Cols>, FaerError>
returns a newly allocated matrix holding the values of self
Sourcepub fn to_col_major(
&self,
) -> Result<SymbolicSparseColMat<I, Rows, Cols>, FaerError>
pub fn to_col_major( &self, ) -> Result<SymbolicSparseColMat<I, Rows, Cols>, FaerError>
returns a newly allocated matrix holding the values of self in column major format
Sourcepub fn compute_nnz(&self) -> usize
pub fn compute_nnz(&self) -> usize
returns the number of non-zero elements in the matrix
Sourcepub fn row_range(&self, i: Idx<Rows>) -> Range<usize>
pub fn row_range(&self, i: Idx<Rows>) -> Range<usize>
returns the range specifying the indices of row i
Sourcepub unsafe fn row_range_unchecked(&self, i: Idx<Rows>) -> Range<usize>
pub unsafe fn row_range_unchecked(&self, i: Idx<Rows>) -> Range<usize>
returns the range specifying the indices of row i, without bound checks
Sourcepub fn col_idx_of_row_raw(&self, i: Idx<Rows>) -> &'a [Idx<Cols, I>] ⓘ
pub fn col_idx_of_row_raw(&self, i: Idx<Rows>) -> &'a [Idx<Cols, I>] ⓘ
returns the column indices of row i
Sourcepub fn col_idx_of_row(
&self,
i: Idx<Rows>,
) -> impl 'a + Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<Cols>>where
Rows: 'a,
Cols: 'a,
pub fn col_idx_of_row(
&self,
i: Idx<Rows>,
) -> impl 'a + Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<Cols>>where
Rows: 'a,
Cols: 'a,
returns the column indices of row i
Sourcepub fn as_shape<V: Shape, H: Shape>(
self,
nrows: V,
ncols: H,
) -> SymbolicSparseRowMatRef<'a, I, V, H>
pub fn as_shape<V: Shape, H: Shape>( self, nrows: V, ncols: H, ) -> SymbolicSparseRowMatRef<'a, I, V, H>
returns the input matrix with the given shape after checking that it matches the current shape
Sourcepub fn as_dyn(self) -> SymbolicSparseRowMatRef<'a, I>
pub fn as_dyn(self) -> SymbolicSparseRowMatRef<'a, I>
returns the input matrix with dynamic shape
Sourcepub fn as_ref(self) -> SymbolicSparseRowMatRef<'a, I, Rows, Cols>
pub fn as_ref(self) -> SymbolicSparseRowMatRef<'a, I, Rows, Cols>
Returns a view over the symbolic structure of self.
Sourceimpl<Rows: Shape, Cols: Shape, I: Index> SymbolicSparseRowMat<Own<I, Rows, Cols>>
impl<Rows: Shape, Cols: Shape, I: Index> SymbolicSparseRowMat<Own<I, Rows, Cols>>
Sourcepub unsafe fn new_unchecked(
nrows: Rows,
ncols: Cols,
row_ptr: Vec<I>,
row_nnz: Option<Vec<I>>,
col_idx: Vec<I>,
) -> Self
pub unsafe fn new_unchecked( nrows: Rows, ncols: Cols, row_ptr: Vec<I>, row_nnz: Option<Vec<I>>, col_idx: Vec<I>, ) -> Self
Sourcepub fn new_checked(
nrows: Rows,
ncols: Cols,
row_ptr: Vec<I>,
row_nnz: Option<Vec<I>>,
col_idx: Vec<I>,
) -> Self
pub fn new_checked( nrows: Rows, ncols: Cols, row_ptr: Vec<I>, row_nnz: Option<Vec<I>>, col_idx: Vec<I>, ) -> Self
Sourcepub fn new_unsorted_checked(
nrows: Rows,
ncols: Cols,
row_ptr: Vec<I>,
row_nnz: Option<Vec<I>>,
col_idx: Vec<I>,
) -> Self
pub fn new_unsorted_checked( nrows: Rows, ncols: Cols, row_ptr: Vec<I>, row_nnz: Option<Vec<I>>, col_idx: Vec<I>, ) -> Self
Sourcepub fn shape(&self) -> (Rows, Cols)
pub fn shape(&self) -> (Rows, Cols)
Sourcepub fn transpose(&self) -> SymbolicSparseColMatRef<'_, I, Cols, Rows>
pub fn transpose(&self) -> SymbolicSparseColMatRef<'_, I, Cols, Rows>
Sourcepub fn into_transpose(self) -> SymbolicSparseColMat<I, Cols, Rows>
pub fn into_transpose(self) -> SymbolicSparseColMat<I, Cols, Rows>
Sourcepub fn to_owned(&self) -> Result<SymbolicSparseRowMat<I, Rows, Cols>, FaerError>
pub fn to_owned(&self) -> Result<SymbolicSparseRowMat<I, Rows, Cols>, FaerError>
Sourcepub fn to_col_major(
&self,
) -> Result<SymbolicSparseColMat<I, Rows, Cols>, FaerError>
pub fn to_col_major( &self, ) -> Result<SymbolicSparseColMat<I, Rows, Cols>, FaerError>
Sourcepub fn compute_nnz(&self) -> usize
pub fn compute_nnz(&self) -> usize
Sourcepub unsafe fn row_range_unchecked(&self, i: Idx<Rows>) -> Range<usize>
pub unsafe fn row_range_unchecked(&self, i: Idx<Rows>) -> Range<usize>
Sourcepub fn col_idx_of_row_raw(&self, i: Idx<Rows>) -> &[Idx<Cols, I>] ⓘ
pub fn col_idx_of_row_raw(&self, i: Idx<Rows>) -> &[Idx<Cols, I>] ⓘ
Sourcepub fn col_idx_of_row(
&self,
i: Idx<Rows>,
) -> impl '_ + Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<Cols>>
pub fn col_idx_of_row( &self, i: Idx<Rows>, ) -> impl '_ + Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<Cols>>
Sourcepub fn as_shape<V: Shape, H: Shape>(
&self,
nrows: V,
ncols: H,
) -> SymbolicSparseRowMatRef<'_, I, V, H>
pub fn as_shape<V: Shape, H: Shape>( &self, nrows: V, ncols: H, ) -> SymbolicSparseRowMatRef<'_, I, V, H>
Sourcepub fn into_shape<V: Shape, H: Shape>(
self,
nrows: V,
ncols: H,
) -> SymbolicSparseRowMat<I, V, H>
pub fn into_shape<V: Shape, H: Shape>( self, nrows: V, ncols: H, ) -> SymbolicSparseRowMat<I, V, H>
Sourcepub fn as_dyn(&self) -> SymbolicSparseRowMatRef<'_, I>
pub fn as_dyn(&self) -> SymbolicSparseRowMatRef<'_, I>
Sourcepub fn into_dyn(self) -> SymbolicSparseRowMat<I>
pub fn into_dyn(self) -> SymbolicSparseRowMat<I>
Sourcepub fn as_ref(&self) -> SymbolicSparseRowMatRef<'_, I, Rows, Cols>
pub fn as_ref(&self) -> SymbolicSparseRowMatRef<'_, I, Rows, Cols>
Returns a view over the symbolic structure of self.
Sourcepub fn try_new_from_indices(
nrows: Rows,
ncols: Cols,
idx: &[Pair<Idx<Rows, I>, Idx<Cols, I>>],
) -> Result<(Self, Argsort<I>), CreationError>
pub fn try_new_from_indices( nrows: Rows, ncols: Cols, idx: &[Pair<Idx<Rows, I>, Idx<Cols, I>>], ) -> Result<(Self, Argsort<I>), CreationError>
create a new symbolic structure, and the corresponding order for the numerical values from pairs of indices
Sourcepub fn try_new_from_nonnegative_indices(
nrows: Rows,
ncols: Cols,
idx: &[Pair<MaybeIdx<Rows, I>, MaybeIdx<Cols, I>>],
) -> Result<(Self, Argsort<I>), CreationError>
pub fn try_new_from_nonnegative_indices( nrows: Rows, ncols: Cols, idx: &[Pair<MaybeIdx<Rows, I>, MaybeIdx<Cols, I>>], ) -> Result<(Self, Argsort<I>), CreationError>
create a new symbolic structure, and the corresponding order for the numerical values from pairs of indices
negative indices are ignored